@@ -13,6 +13,9 @@ class LoggingSentryClient(SentryClient):
     
     def send(self, **kwargs):
         exc_info = sys.exc_info()
-        self.logger.log(kwargs.pop('level', None) or self.default_level,
-                        kwargs.pop('message', None) or exc_info[0],
-                        exc_info=exc_info, extra=kwargs)
+        try:
+            self.logger.log(kwargs.pop('level', None) or self.default_level,
+                            kwargs.pop('message', None) or exc_info[0],
+                            exc_info=exc_info, extra=kwargs)
+        finally:
+            del exc_info
