@@ -43,13 +43,13 @@ if settings.SEARCH_ENGINE:
             return '\n'.join(map(to_unicode, filter(None, chunks)))
 
         def prepare_server(self, instance):
-            return [to_unicode(s['server_name']) for s in instance.unique_servers]
+            return [to_unicode(s[0]) for s in instance.unique_servers]
 
         def prepare_site(self, instance):
-            return [to_unicode(s['site']) for s in instance.unique_sites]
+            return [to_unicode(s[0]) for s in instance.unique_sites]
 
         def prepare_url(self, instance):
-            return [to_unicode(s['url']) for s in instance.unique_urls]
+            return [to_unicode(s[0]) for s in instance.unique_urls]
 
 
     site.register(GroupedMessage, GroupedMessageIndex)
